aboutsummaryrefslogtreecommitdiff
path: root/SRC/ssytrf_aa.f
diff options
context:
space:
mode:
authorIchitaro Yamazaki <iyamazak@bunsen.icl.utk.edu>2016-11-17 16:25:09 -0500
committerIchitaro Yamazaki <iyamazak@bunsen.icl.utk.edu>2016-11-17 16:25:09 -0500
commit8b4f3fd9a349567fb71ed8decb1c83a090b9e6b2 (patch)
tree8c6b2cf32400318a7190d9904e12229d4d7a2f35 /SRC/ssytrf_aa.f
parentc273c5da1de722032cbdbb7d541c6157141e2dbb (diff)
fixing lwork for Aasen's (lwork > 0).
Diffstat (limited to 'SRC/ssytrf_aa.f')
-rw-r--r--SRC/ssytrf_aa.f4
1 files changed, 2 insertions, 2 deletions
diff --git a/SRC/ssytrf_aa.f b/SRC/ssytrf_aa.f
index 13498c9b..a22ff05d 100644
--- a/SRC/ssytrf_aa.f
+++ b/SRC/ssytrf_aa.f
@@ -101,7 +101,7 @@
*> \param[in] LWORK
*> \verbatim
*> LWORK is INTEGER
*> The length of WORK. LWORK >=2*N. For optimum performance
*> LWORK >= N*(1+NB), where NB is the optimal blocksize.
*>
*> If LWORK = -1, then a workspace query is assumed; the routine
@@ -191,7 +191,7 @@
INFO = -2
ELSE IF( LDA.LT.MAX( 1, N ) ) THEN
INFO = -4
- ELSE IF( LWORK.LT.( 2*N ) .AND. .NOT.LQUERY ) THEN
+ ELSE IF( LWORK.LT.MAX( 1, 2*N ) .AND. .NOT.LQUERY ) THEN
INFO = -7
END IF
*
@@ -101,7 +101,7 @@
*> \verbatim
*> LWORK is INTEGER
-*> The length of WORK. LWORK >=2*N. For optimum performance
+*> The length of WORK. LWORK >= MAX(1,2*N). For optimum performance
*> LWORK >= N*(1+NB), where NB is the optimal blocksize.
*>